/*Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana

This file is part of Plataforma Integrada MEC.

Plataforma Integrada MEC is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Plataforma Integrada MEC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Plataforma Integrada MEC.  If not, see <http://www.gnu.org/licenses/>.*/

import React, { useState, useEffect, useContext } from 'react';
//imports material ui components
import { Typography, Grid } from '@material-ui/core';
import CircularProgress from '@material-ui/core/CircularProgress';
import CardContent from "@material-ui/core/CardContent";
import CardAction from '@material-ui/core/CardActions';
import ListRoundedIcon from '@material-ui/icons/ListRounded';
import SaveIcon from '@material-ui/icons/Save';
//imports local files
import SnackBar from '../../../../Components/SnackbarComponent';
import LoadingSpinner from '../../../../Components/LoadingSpinner';
import { StyledCard } from "../../../Components/Styles/DataCard";
import { Store } from 'Store'
import FormInput from "Components/FormInput.js"
import StyledButton from '../Button';
//imports services 
import { getRequest, putRequest } from '../../../../Components/HelperFunctions/getAxiosConfig'
import { EditFilter, GetAData } from '../../../Filters';
//routers
import { Link } from 'react-router-dom';

const EditRating = () => {

    const { state } = useContext(Store);

    const urlParams = new URLSearchParams(window.location.search);
    const id = urlParams.get("rating");

    const [error, setError] = useState(null); //Necessary to consult the API, catch errors
    const [isLoaded, setIsLoaded] = useState(false); //Necessary to consult the API, wait until complete

    const [isLoading, setIsLoading] = useState(false);
    const [name, setName] = useState()
    const [description, setDescription] = useState()

    const [errorInName, setErrorInName] = useState({
        error: false,
        message: ''
    })

    const [errorInDescription, setErrorInDescription] = useState({
        error: false,
        message: ''
    })

    const [snackInfo, setSnackInfo] = useState({
        message: '',
        icon: '',
        open: false,
        color: '',
    })

    const NameHandler = (e) => {
        if (errorInName.error) {
            setErrorInName({
                error: false,
                message: ''
            })
        }
        setName(e.target.value)
    }

    const DescriptionHandler = (e) => {
        if (errorInDescription.error) {
            setErrorInDescription({
                error: false,
                message: ''
            })
        }
        setDescription(e.target.value)
    }


    //Verify if the string is empty
    const isEmpty = (text) => {
        return text.length === 0 ? true : false;
    }

    // Fields
    const fields = [
        {
            label: 'ID',
            value: id,
            default: true,
            type: 'text'
        },
        {
            label: 'Nome',
            value: name,
            error: errorInName.error,
            errorMessage: errorInName.message,
            onChange: (event) => NameHandler(event),
            default: false,
            required: true,
            type: 'text',
        },
        {
            label: 'Descrição',
            value: description,
            error: errorInDescription.error,
            errorMessage: errorInDescription.message,
            onChange: (event) => DescriptionHandler(event),
            default: false,
            required: true,
            type: 'text'
        },
    ]

    // Handle snack infos
    const HandleSnack = (message, state, icon, color) => {
        setSnackInfo({
            message: message,
            icon: icon,
            open: state,
            color: color
        })
    }

    const onSubmit = async () => {
        setIsLoading(true)
        if (!isEmpty(name) && !isEmpty(description)) {
            const api = EditFilter('ratings', id)
            const body = {
                "rating": {
                    'name': name,
                    'description': description,
                }
            }
            putRequest(
                api,
                body,
                (data, header) => {
                    if (data.errors)
                        HandleSnack('Ocorreu algum erro', true, 'warning', '#FA8072')
                    else
                        HandleSnack('O rating foi alterada com sucesso', true, 'success', '#228B22')
                    setIsLoading(false)
                },
                (error) => {
                    HandleSnack('Ocorreu algum erro', true, 'warning', '#FA8072')
                    setIsLoading(false)
                }
            )
        }
        else {
            HandleSnack('Você precisa preencher algumas informações obrigatórias', true, 'warning', '#FFC125')
            if (isEmpty(name)) {
                setErrorInName({
                    error: true,
                    message: 'Este campo precisa ser preenchido'
                })
            }
            if (isEmpty(description)) {
                setErrorInDescription({
                    error: true,
                    message: 'Este campo precisa ser preenchido'
                })
            }
            setIsLoading(false)
        }
    }

    useEffect(() => {
        getRequest(
            GetAData("ratings", id),
            (data, header) => {
                setIsLoaded(true);
                setName(data.name)
                setDescription(data.description)
            },
            (error) => {
                setIsLoaded(true);
                setError(true);
            }
        )
    }, []);

    if (error) {
        return <div> Houve um erro... </div>
    } else if (!isLoaded) {
        return <LoadingSpinner text="Carregando..." />
    } else {
        return (
            <StyledCard contrast={state.contrast}>
                <SnackBar
                    severity={snackInfo.icon}
                    text={snackInfo.message}
                    snackbarOpen={snackInfo.open}
                    color={snackInfo.color}
                    handleClose={() => setSnackInfo({
                        message: '',
                        icon: '',
                        open: false,
                        color: ''
                    })}
                />
                <CardContent>
                    <Grid container direction='row' justify='space-between' alignContent="center" alignItems="center" xs={12}>
                        <Grid item>
                            <Typography variant='h4'>
                                {name}
                            </Typography>
                        </Grid>
                        <Grid item>
                            <Link style={{ textDecoration: 'none' }} to={'/admin/Ratings'}>
                                <StyledButton
                                    icon={<ListRoundedIcon />}
                                    variant='outlined'
                                    color='primary'
                                    text="Listar"
                                />
                            </Link>
                        </Grid>
                    </Grid>

                    <div style={{ height: '1em' }}></div>

                    <form style={{ display: 'flex', flexDirection: 'column' }}>
                        {fields.map((field, index) => (
                            <FormInput
                                contrast={state.contrast}
                                key={index}
                                required={field.required}
                                disableField={field.default}
                                error={field.error}
                                help={field.error ? field.errorMessage : ''}
                                style={{ width: '250px', marginBottom: '1em' }}
                                placeholder={field.label}
                                value={field.value}
                                handleChange={field.onChange}
                                inputType="search"
                                multi={true}
                            />
                        ))}
                    </form>
                </CardContent>
                <CardAction>
                    <StyledButton
                        onClick={() => {
                            onSubmit();
                        }}
                        variant="contained"
                        color="primary"
                        disabled={isLoading}
                        icon={isLoading ? null : <SaveIcon />}
                        text={
                            isLoading ? <CircularProgress size={24} /> : 'Salvar'
                        }
                    />
                </CardAction>
            </StyledCard>
        )
    }
}

export default EditRating;