/*Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana

This file is part of Plataforma Integrada MEC.

Plataforma Integrada MEC is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Plataforma Integrada MEC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Plataforma Integrada MEC.  If not, see <http://www.gnu.org/licenses/>.*/
import React, { useEffect, useState, useContext } from 'react';
import moment from "moment";
//Material ui componets
import TableBody from '@material-ui/core/TableBody';
import Grid from "@material-ui/core/Grid";
import Paper from "@material-ui/core/Paper";
import MenuItem from "@material-ui/core/MenuItem";
import TableRow from "@material-ui/core/TableRow";
import TableCell from '@material-ui/core/TableCell';
import RemoveCircleOutlineRoundedIcon from '@material-ui/icons/RemoveCircleOutlineRounded';
import VisibilityIcon from '@material-ui/icons/Visibility';
import { Button } from '@material-ui/core';
import CircularProgress from '@material-ui/core/CircularProgress';
import AddRoundedIcon from '@material-ui/icons/AddRounded';
import UpdateRoundedIcon from '@material-ui/icons/UpdateRounded'
import EmailRoundedIcon from '@material-ui/icons/EmailRounded';
//Local files
import TableData from '../../../Components/Components/Table';
import SnackBar from '../../../../Components/SnackbarComponent';
import LoadingSpinner from '../../../../Components/LoadingSpinner';
import MobileList from "../../../Components/Components/MobileComponents/SimpleList"
import { apiDomain } from '../../../../env';
import MobilePageHeader from "../../../Components/Components/MobileComponents/MobilePageHeader"
import PageHeader, { StyledFilter } from "../../../Components/Components/PageHeader"
import { StyledLoadMoreButton, StyledDivButton, useStylesCell, useStylesRow } from "./Collections.js";
import { Store } from 'Store'
import StyledButton from '../../../Components/Components/Button';
import FormInput from "Components/FormInput.js"
//Services
import { getRequest, putRequest } from '../../../../Components/HelperFunctions/getAxiosConfig'
import { Url } from '../../../Filters';
//routers
import { Link } from 'react-router-dom';

//Image Import
import { noAvatar } from "ImportImages.js";

const BlockedUsers = () => {

    const { state } = useContext(Store)

    const classesCell = useStylesCell(state);
    const classesRow = useStylesRow(state);

  const ADD_ONE_LENGHT = [''];
  const WINDOW_WIDTH = window.innerWidth

  const [invertList, setInvertList] = useState(false)
  const [error, setError] = useState(null); //Necessary to consult the API, catch errors
  const [isLoaded, setIsLoaded] = useState(false); //Necessary to consult the API, wait until complete 
  const [items, setItems] = useState([]); //Necessary to consult the API, data
  const [isLoadingMoreItems, setIsLoadingMoreItems] = useState(false)
  const [stateOpt, setStateOpt] = useState(1)
  const [currPage, setCurrPage] = useState(0)
  const [forceUpdate, setForceUpdate] = useState(false)

  const [snackInfo, setSnackInfo] = useState({
    message: '',
    icon: '',
    open: false,
    color: '',
  })

  const StateOptions = [
    {
      name: 1,
      value: "Semanal"
    },
    {
      name: 2,
      value: "Permanente"
    }
  ];

  // Handle snack infos
  const HandleSnack = (message, state, icon, color) => {
    setSnackInfo({
      message: message,
      icon: icon,
      open: state,
      color: color
    })
  }

  const handleChange = (event) => {
    const type = event.target.value
    setStateOpt(type)
  }

  const BlockStatus = (status) => {
    switch (status) {
      case "blocked":
        return (
          <Paper
            style={{
              textAlign: "center",
              padding: "0.5em",
              backgroundColor: state.contrast === "" ? "#FF8C00" : "black",
              border: state.contrast === "" ? "" : "1px solid white",
              fontWeight: "500",
              color: "#FFFAFA",
            }}
          >
            SEMANAL
          </Paper>
        );
      case "banished":
        return (
          <Paper
            style={{
              textAlign: "center",
              padding: "0.5em",
              backgroundColor: state.contrast === "" ? "red" : "black",
              border: state.contrast === "" ? "" : "1px solid white",
              fontWeight: "500",
              color: "#FFFAFA",
            }}
          >
            PERMANENTE
          </Paper>
        );
      default:
        return (
          <Paper
            style={{
              textAlign: "center",
              padding: "0.5em",
              backgroundColor: state.contrast === "" ? "#797D7F" : "black",
              border: state.contrast === "" ? "" : "1px solid white",
              fontWeight: "500",
              color: "#FFFAFA",
            }}
          >
            Não avaliado
          </Paper>
        );
    }
  };

  const ReactiveUser = (userId, index) => {
    putRequest(
      `/users/${userId}/reactivate_user`,
      {},
      (data) => {
        if (data.errors)
          HandleSnack('Erro!', true, 'warning', '#FA8072')
        else {
          HandleSnack('Usuário foi reativado com sucesso!', true, 'success', '#228B22')
          removeItemFromList(index)
          setCurrPage(0)
        }
      },
      (error) => {
        HandleSnack('Erro!', true, 'warning', '#FA8072')
      }
    )
  }

  const removeItemFromList = (index) => {
    const copyList = [...items]
    copyList.splice(index, 1)
    setItems(copyList)
  }

  const DisplayDate = (date) => {
    const convertedData = moment.utc(date);
    return moment(convertedData)
      .format("LLL")
      .toString();
  };

  const cleanArrayAndInvert = () => {
    setInvertList(!invertList)
    setCurrPage(0)
    setItems([])
  }

  useEffect(() => {
    if (currPage === 0)
      setIsLoaded(false)
    else
      setIsLoadingMoreItems(true)
    getRequest(
      Url('users', `"state" : ${stateOpt}`, currPage, invertList ? "ASC" : 'DESC'),

      (data, header) => {
        const arrData = [...data]
        if (arrData.length === 0) {
          HandleSnack('Não há mais dados para serem carregados', true, 'warning', '#FFC125')
        } else {
          const arrItems = [...items]
          if (currPage === 0) {
            setItems(arrData.concat(ADD_ONE_LENGHT))
          }
          else {
            arrItems.pop(); //Deleting the last position, that was used to display the button of load more items 
            const arrResult = arrItems.concat(arrData)
            setItems(arrResult.concat(ADD_ONE_LENGHT))
          }
        }
        setIsLoaded(true)
        setIsLoadingMoreItems(false)
      },
      (error) => {
        HandleSnack('Erro ao carregar os dados', true, 'warning', '#FA8072')
        setIsLoadingMoreItems(false)
        setIsLoaded(true)
        setError(true)
      }
    )
  }, [currPage, stateOpt, invertList, forceUpdate])

  if (error) {
    return <div>Error: {error.message}</div>;
  } else if (!isLoaded) {
    return <LoadingSpinner text="Carregando..." />
  } else {

    //Words in the top part of the table
    const topTable = ['ID', 'ESTADO', 'NAME', 'EMAIL', 'BLOQUEADO EM', 'AÇÕES'];
    if (WINDOW_WIDTH <= 899) {
      return (
        <div>
          <SnackBar
            severity={snackInfo.icon}
            text={snackInfo.message}
            snackbarOpen={snackInfo.open}
            color={snackInfo.color}
            handleClose={() => setSnackInfo({
              message: '',
              icon: '',
              open: false,
              color: ''
            })}
          />
          <MobilePageHeader
            title="Lista de usuários bloqueados"
            actions={[
              {
                name: "Atualizar",
                isLoading: false,
                func: () => {
                  setCurrPage(0)
                  setForceUpdate(!forceUpdate)
                },
                icon: <UpdateRoundedIcon />
              },
              {
                name: "Inverter lista",
                isLoading: false,
                func: () => {
                  cleanArrayAndInvert()
                },
              },
            ]}
          >
              <StyledFilter contrast={state.contrast}>
            <Grid item>
                <FormInput
                    contrast={state.contrast}
                    selectable={true}
                    placeholder="Estado de bloqueio"
                    handleChange={handleChange}
                    help="Por favor, selecione uma das opções"
                    items={StateOptions.map((option, index) => (
                        <MenuItem
                            key={option.value}
                            value={option.name}
                            name={option.value}
                            className={`${state.contrast}BackColor ${state.contrast}LinkColor`}
                        >
                            {option.value}
                        </MenuItem>
                    ))}
                />
            </Grid>
            </StyledFilter>
          </MobilePageHeader>

          {items.map((row, index) =>
            index === items.length - 1 ? (
              <StyledDivButton contrast={state.contrast}>
                <StyledLoadMoreButton
                  contrast={state.contrast}
                  key={new Date().toISOString() + row.created_at}
                  color="primary"
                  variant="text"
                  // disabled={isLoadingMoreItems}
                  startIcon={<AddRoundedIcon />}
                  disabled={isLoadingMoreItems}
                  onClick={() => {
                    setCurrPage(currPage + 1)
                  }}
                >
                  {isLoadingMoreItems ? (
                    <CircularProgress size={24} />
                  ) : (
                      "Carregar mais itens"
                    )}
                </StyledLoadMoreButton>
              </StyledDivButton>
            ) : (
                <>
                  <MobileList
                    contrast={state.contrast}
                    key={new Date().toISOString() + row.created_at}
                    title={row.name}
                    subtitle={row.id}
                    backColor={"#e81f4f"}
                    avatar={
                      <img
                        src={row.avatar ? apiDomain + row.avatar : noAvatar}
                        alt="user avatar"
                        style={{
                          height: "100%",
                          width: "100%",
                          borderRadius: "50%",
                        }}
                      />
                    }
                    href={`/admin/user?id=${row.id}`}
                    reset={() => {
                    }}
                    data={
                      [
                        {
                          title: "Email",
                          subtitle: row.email ?
                            <Link to={`/admin/sendEmail?email=${row.email}`} style={{ textDecoration: 'none' }}>
                              <StyledButton
                                variant='text'
                                color="primary"
                                icon={<EmailRoundedIcon style={state.contrast === "" ? {color: "#666"} : {color: "white"}}/>}
                                text={row.email}
                              />
                            </Link> : null
                        },
                        {
                          title: "Estado",
                          subtitle: BlockStatus(row.state)
                        },
                        {
                          title: "Ações rápidas",
                          subtitle: <StyledButton
                            style={{ width: "100%", marginBottom: "0.5em" }}
                            variant="contained"
                            color="secondary"
                            icon={<RemoveCircleOutlineRoundedIcon />}
                            onClick={() => ReactiveUser(row.id, index)}
                            text="Desbloquear"
                          />
                        }
                      ]
                    }
                  />
                </>
              )
          )}
        </div>
      )
    }
    else {
      return (
        <div>
          <SnackBar
            severity={snackInfo.icon}
            text={snackInfo.message}
            snackbarOpen={snackInfo.open}
            color={snackInfo.color}
            handleClose={() => setSnackInfo({
              message: '',
              icon: '',
              open: false,
              color: ''
            })}
          />
          <PageHeader
            title="Lista de usuários bloqueados"
            actions={[
              {
                name: "Atualizar",
                isLoading: false,
                func: () => {
                  setCurrPage(0)
                  setForceUpdate(!forceUpdate)
                },
                icon: <UpdateRoundedIcon />
              },
            ]}
          >
              <StyledFilter contrast={state.contrast}>
            <Grid item>
                <FormInput
                    contrast={state.contrast}
                    selectable={true}
                    placeholder="Estado de bloqueio"
                    handleChange={handleChange}
                    help="Por favor, selecione uma das opções"
                    items={StateOptions.map((option, index) => (
                        <MenuItem
                            key={option.value}
                            value={option.name}
                            name={option.value}
                            className={`${state.contrast}BackColor ${state.contrast}LinkColor`}
                        >
                            {option.value}
                        </MenuItem>
                    ))}
                />
            </Grid>
            </StyledFilter>
          </PageHeader>

          <TableData
            top={topTable}
            onIconPressed={cleanArrayAndInvert}
          >
            <TableBody>
              {items.map((row, index) => (
                index === items.length - 1 ?
                  <TableRow className={classesRow.root} key={new Date().toISOString() + row.created_at}>
                    {/* Button to load more data */}
                    <TableCell className={classesCell.root} colspan={6}>
                      <Button
                        color='primary'
                        variant='text'
                        disabled={isLoadingMoreItems}
                        startIcon={<AddRoundedIcon />}
                        onClick={() => {
                          setCurrPage(currPage + 1)
                        }}
                        style={state.contrast === "" ? {width: "100%"} : {width: "100%", color: "yellow", textDecoration: "underline yellow"}}
                      >
                        {
                          isLoadingMoreItems ? <CircularProgress size={24} /> : 'Carregar mais itens'
                        }
                      </Button>
                    </TableCell>
                  </TableRow>

                  :

                  <TableRow className={classesRow.root} key={new Date().toISOString() + index}>
                    <TableCell className={classesCell.root} component="th" scope="row">{row.id}</TableCell>
                    <TableCell className={classesCell.root} align="right">
                      {BlockStatus(row.state)}
                    </TableCell>
                    <TableCell className={classesCell.root} align="right">{row.name}</TableCell>
                    <TableCell className={classesCell.root} align="right">
                        {
                            row.email ?
                            <Link to={`/admin/sendEmail?email=${row.email}`} style={{ textDecoration: 'none' }}>
                              <StyledButton
                                variant='text'
                                color="primary"
                                icon={<EmailRoundedIcon style={state.contrast === "" ? {color: "#666"} : {color: "white"}}/>}
                                text={row.email}
                              />
                            </Link> : null
                        }
                    </TableCell>
                    <TableCell className={classesCell.root} align="right">
                      {DisplayDate(row.suspended_at)}
                    </TableCell>
                    <TableCell className={classesCell.root} align="right">
                      <StyledButton
                        style={{ width: "100%", marginBottom: "0.5em" }}
                        variant="contained"
                        color="secondary"
                        icon={<RemoveCircleOutlineRoundedIcon />}
                        onClick={() => ReactiveUser(row.id, index)}
                        text="Desbloquear"
                      />
                      <Link to={`/admin/user?id=${row.id}`}>
                        <StyledButton
                          style={{ width: "100%" }}
                          variant="contained"
                          color="primary"
                          icon={<VisibilityIcon />}
                          text="Visualizar"
                        />
                      </Link>
                    </TableCell>
                  </TableRow>
              ))}
            </TableBody>
          </TableData>
        </div>
      )
    }
  }
}


export default BlockedUsers;