/*Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana

This file is part of Plataforma Integrada MEC.

Plataforma Integrada MEC is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Plataforma Integrada MEC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Plataforma Integrada MEC.  If not, see <http://www.gnu.org/licenses/>.*/
import React, { useEffect, useState, useContext } from 'react';
//Material ui componets
import TableBody from '@material-ui/core/TableBody';
import Grid from "@material-ui/core/Grid";
import TableCell from '@material-ui/core/TableCell';
import TableRow from '@material-ui/core/TableRow';
import IconButton from '@material-ui/core/IconButton';
import VisibilityIcon from '@material-ui/icons/Visibility';
import { Button, Chip } from '@material-ui/core';
import CircularProgress from '@material-ui/core/CircularProgress';
import AddRoundedIcon from '@material-ui/icons/AddRounded';
import UpdateRoundedIcon from '@material-ui/icons/UpdateRounded'
import FilterListRoundedIcon from "@material-ui/icons/FilterListRounded";
//Local files
import TableData from '../../../Components/Components/Table';
import SnackBar from '../../../../Components/SnackbarComponent';
import LoadingSpinner from '../../../../Components/LoadingSpinner';
import MobileList from "../../../Components/Components/MobileComponents/SimpleList"
import MobilePageHeader from "../../../Components/Components/MobileComponents/MobilePageHeader"
import PageHeader, { StyledFilter } from "../../../Components/Components/PageHeader"
import FormInput from "Components/FormInput.js"
import { Store } from 'Store'
import { StyledLoadMoreButton, StyledDivButton, useStylesCell, useStylesRow } from './Collections';
import StyledButton from '../../../Components/Components/Button';
//Services
import { getRequest, putRequest } from '../../../../Components/HelperFunctions/getAxiosConfig'
import { Url } from '../../../Filters';
//routers
import { Link, useHistory } from 'react-router-dom';
import moment from 'moment';
import styled from 'styled-components'
import EmailRoundedIcon from '@material-ui/icons/EmailRounded';
import { apiDomain } from '../../../../env';

//Image Import
import { noAvatar } from "ImportImages.js";

const Users = () => {

    const { state } = useContext(Store)

    const classesCell = useStylesCell(state);
    const classesRow = useStylesRow(state);

  const ADD_ONE_LENGHT = [''];
  const WINDOW_WIDTH = window.innerWidth

  const router = useHistory()

  const [invertList, setInvertList] = useState(false)
  const [error, setError] = useState(null); //Necessary to consult the API, catch errors
  const [isLoaded, setIsLoaded] = useState(false); //Necessary to consult the API, wait until complete 
  const [items, setItems] = useState([]); //Necessary to consult the API, data
  const [isLoadingMoreItems, setIsLoadingMoreItems] = useState(false)
  const [showFilter, setShowFilter] = useState(false)
  const [currPage, setCurrPage] = useState(0)
  const [forceUpdate, setForceUpdate] = useState(false)

  const [name, setName] = useState("");
  const [nameValue, setNameValue] = useState("")
  const [email, setEmail] = useState("");
  const [emailValue, setEmailValue] = useState("")

  const [snackInfo, setSnackInfo] = useState({
    message: '',
    icon: '',
    open: false,
    color: '',
  })

  // Handle snack infos
  const HandleSnack = (message, state, icon, color) => {
    setSnackInfo({
      message: message,
      icon: icon,
      open: state,
      color: color
    })
  }

  const NameHandler = (event) => {
    setNameValue(event.target.value)
  }

  const EmailHandler = (event) => {
    setEmailValue(event.target.value)
  }

  const DisplayDate = (date) => {
    const convertedData = moment.utc(date);
    return moment(convertedData)
      .format("LLL")
      .toString();
  };

  const isUserPublisher = (userRoles) => {
    for (let index = 0; index < userRoles.length; index++) {
      if (userRoles[index].id === 10)
        return true;
    }
    return false;
  }

  const pushPublisherRole = (userId) => {
    let index = -1;
    for (let i = 0; i < items.length; i++) {
      const element = items[i];
      if (element.id === userId) {
        index = i
        break
      }
    }
    if (index !== -1) {
      const cpyItems = [...items]
      cpyItems[index].roles.push({
        id: 10,
        name: "publisher"
      })
      setItems(cpyItems)
    }
  }

  const turnUserPublisher = (userRoles, userId) => {
    let roles_ids = [];
    userRoles.map((role) => (
      roles_ids.push(role.id)
    ))
    roles_ids.push(10);
    const body = {
      "user": {
        "role_ids": roles_ids
      }
    }
    putRequest(
      `/users/${userId}`,
      body,
      (data) => {
        if (data.errors) {
          HandleSnack('Ocorreu algum erro', true, 'warning', '#FA8072')
        }
        else {
          HandleSnack(`O usuário ${userId}, agora é publicador`, true, 'success', '#228B22')
          pushPublisherRole(userId)
          setCurrPage(0)
        }
      },
      (error) => {
        HandleSnack('Ocorreu algum erro', true, 'warning', '#FA8072')
      }
    )
  }

  const cleanArrayAndInvert = () => {
    setInvertList(!invertList)
    setCurrPage(0)
    setItems([])
  }

  const buildUrl = (email, name, direction) => {
    if (email && name)
      return Url("users", `"email" : "${email}", "name" : "${name}"`, currPage, direction)
    if (email)
      return Url("users", `"email" : "${email}"`, currPage, direction)
    if (name)
      return Url("users", `"name" : "${name}"`, currPage, direction)
    else
      return Url("users", "", currPage, direction)
  }

  useEffect(() => {
    if (currPage === 0)
      setIsLoaded(false)
    else
      setIsLoadingMoreItems(true)
    getRequest(
      buildUrl(email, name, invertList ? "ASC" : "DESC"),
      (data, header) => {
        const arrData = [...data]
        if (arrData.length === 0) {
          HandleSnack('Não há mais dados para serem carregados', true, 'warning', '#FFC125')
        } else {
          const arrItems = [...items]
          if (currPage === 0) {
            setItems(arrData.concat(ADD_ONE_LENGHT))
          }
          else {
            arrItems.pop(); //Deleting the last position, that was used to display the button of load more items 
            const arrResult = arrItems.concat(arrData)
            setItems(arrResult.concat(ADD_ONE_LENGHT))
          }
        }
        setIsLoaded(true)
        setIsLoadingMoreItems(false)
      },
      (error) => {
        HandleSnack('Erro ao carregar os dados', true, 'warning', '#FA8072')
        setIsLoaded(true)
        setError(true)
        setIsLoadingMoreItems(false)
      }
    )
  }, [currPage, email, name, invertList, forceUpdate])

  useEffect(() => {
    setNameValue("")
    setName("")
    setEmailValue("")
    setEmail("")
  }, [showFilter])

  if (error) {
    return <div>Error: {error.message}</div>;
  } else if (!isLoaded) {
    return <LoadingSpinner text="Carregando..." />
  } else {

    //Words in the top part of the table
    const topTable = ['ID', 'NOME', 'EMAIL', 'CRIADO EM', 'SCORE', 'PERMISSÃO', 'AÇÃO', "VISUALIZAR"];
    if (WINDOW_WIDTH <= 1150) {
      return (
        <div>
          <SnackBar
            severity={snackInfo.icon}
            text={snackInfo.message}
            snackbarOpen={snackInfo.open}
            color={snackInfo.color}
            handleClose={() => setSnackInfo({
              message: '',
              icon: '',
              open: false,
              color: ''
            })}
          />
          <MobilePageHeader
            title="Lista de usuários"
            actions={[
              {
                name: "Atualizar",
                isLoading: false,
                func: () => {
                  setCurrPage(0)
                  setForceUpdate(!forceUpdate)
                },
                icon: <UpdateRoundedIcon />
              },
              {
                name: "Filtrar",
                isLoading: false,
                func: () => {
                  setShowFilter(!showFilter);
                },
                icon: <FilterListRoundedIcon />
              },
              {
                name: "Novo",
                isLoading: false,
                func: () => {
                  router.push('/admin/EditUser?id=-1')
                },
                icon: <AddRoundedIcon />
              },
              {
                name: "Inverter lista",
                isLoading: false,
                func: () => {
                  cleanArrayAndInvert()
                },
              }
            ]}
          >
            {
              showFilter ? (
                <StyledFilter contrast={state.contrast}>
                <Grid container direction="row" justify="space-between" alignItems="center">
                  <Grid item>
                    <FormInput
                        contrast={state.contrast}
                        placeholder="Name"
                        handleChange={(e) => { NameHandler(e) }}
                        onBlur={(e) => { setName(e.target.value) }}
                        value={nameValue}
                        help="Ao digitar, retire o foco do campo"
                    />
                  </Grid>
                  <Grid item>
                    <FormInput
                        contrast={state.contrast}
                        placeholder="Email"
                        handleChange={(e) => { EmailHandler(e) }}
                        onBlur={(e) => { setEmail(e.target.value) }}
                        value={emailValue}
                        help="Ao digitar, retire o foco do campo"
                    />
                  </Grid>
                </Grid>
                </StyledFilter>
              ) : null
            }
          </MobilePageHeader>

          {items.map((row, index) =>
            index === items.length - 1 ? (
              <StyledDivButton contrast={state.contrast} key={new Date().toISOString() + row.created_at}>
                <StyledLoadMoreButton
                  contrast={state.contrast}
                  color="primary"
                  variant="text"
                  // disabled={isLoadingMoreItems}
                  startIcon={<AddRoundedIcon />}
                  disabled={isLoadingMoreItems}
                  onClick={() => {
                    setCurrPage(currPage + 1)
                  }}
                >
                  {isLoadingMoreItems ? (
                    <CircularProgress size={24} />
                  ) : (
                      "Carregar mais itens"
                    )}
                </StyledLoadMoreButton>
              </StyledDivButton>
            ) : (
                <>
                  <MobileList
                    contrast={state.contrast}
                    key={new Date().toISOString() + row.created_at}
                    title={row.name}
                    subtitle={row.id}
                    backColor={"#00bcd4"}
                    avatar={
                      <img
                        src={row.avatar ? apiDomain + row.avatar : noAvatar}
                        alt="user avatar"
                        style={{
                          height: "100%",
                          width: "100%",
                          borderRadius: "50%",
                        }}
                      />
                    }
                    href={`/admin/user?id=${row.id}`}
                    reset={() => {
                    }}
                    data={[
                      {
                        title: "Email",
                        subtitle: row.email ?
                          <Link to={`/admin/sendEmail?email=${row.email}`} style={{ textDecoration: 'none' }}>
                            <StyledButton
                              variant='text'
                              color="primary"
                              icon={<EmailRoundedIcon style={state.contrast === "" ? {color: "#666"} : {color: "white"}}/>}
                              text={row.email}
                            />
                          </Link> : null
                      },
                      {
                        title: "Criado em",
                        subtitle: DisplayDate(row.created_at)
                      },
                      {
                        title: "Score",
                        subtitle: row.score
                      },
                      {
                        title: "Permissão",
                        subtitle: row.roles.map((chip) => (
                          <ChipDiv>
                            <Chip label={chip.name} key={chip.id} 
                              style={state.contrast === "" ? {backgroundColor: "#ddd", color: "black"} : {backgroundColor: "black", color: "white", border: "1px solid white"}}
                            />
                          </ChipDiv>
                        ))
                      },
                      {
                        title: "Score",
                        subtitle: row.score
                      },
                      {
                        title: "Ações rápidas",
                        subtitle: <StyledButton
                          variant="contained"
                          color="primary"
                          disabled={isUserPublisher(row.roles)}
                          onClick={() => { turnUserPublisher(row.roles, row.id) }}
                          text="Tornar publicador"
                        />
                      }

                    ]}
                  />
                </>
              )
          )}
        </div>
      )
    }
    else {
      return (
        <div>
          <SnackBar
            severity={snackInfo.icon}
            text={snackInfo.message}
            snackbarOpen={snackInfo.open}
            color={snackInfo.color}
            handleClose={() => setSnackInfo({
              message: '',
              icon: '',
              open: false,
              color: ''
            })}
          />
          <PageHeader
            title="Lista de usuários"
            actions={[
              {
                name: "Atualizar",
                isLoading: false,
                func: () => {
                  setCurrPage(0)
                  setForceUpdate(!forceUpdate)
                },
                icon: <UpdateRoundedIcon />
              },
              {
                name: "Filtrar",
                isLoading: false,
                func: () => {
                  setShowFilter(!showFilter);
                },
                icon: <FilterListRoundedIcon />
              },
              {
                name: "Novo",
                isLoading: false,
                func: () => {
                  router.push('/admin/EditUser?id=-1')
                },
                icon: <AddRoundedIcon />
              }
            ]}
          >
            {
              showFilter ? (
                <StyledFilter contrast={state.contrast}>
                <Grid container direction="row" justify="space-between" alignItems="center">
                  <Grid item>
                    <FormInput
                        contrast={state.contrast}
                        placeholder="Name"
                        handleChange={(e) => { NameHandler(e) }}
                        onBlur={(e) => { setName(e.target.value) }}
                        value={nameValue}
                        help="Ao digitar, retire o foco do campo"
                    />
                  </Grid>
                  <Grid item>
                    <FormInput
                        contrast={state.contrast}
                        placeholder="Email"
                        handleChange={(e) => { EmailHandler(e) }}
                        onBlur={(e) => { setEmail(e.target.value) }}
                        value={emailValue}
                        help="Ao digitar, retire o foco do campo"
                    />
                  </Grid>
                </Grid>
                </StyledFilter>
              ) : null
            }
          </PageHeader>

          <TableData
            top={topTable}
            onIconPressed={cleanArrayAndInvert}
          >
            <TableBody>
              {items.map((row, index) => (
                index === items.length - 1 ?
                  <TableRow className={classesRow.root} key={new Date().toISOString() + row.created_at}>
                    {/* Button to load more data */}
                    <TableCell className={classesCell.root} colspan={8}>
                      <Button
                        color='primary'
                        variant='text'
                        disabled={isLoadingMoreItems}
                        startIcon={<AddRoundedIcon />}
                        onClick={() => {
                          setCurrPage(currPage + 1)
                        }}
                        style={state.contrast === "" ? {width: "100%"} : {width: "100%", color: "yellow", textDecoration: "underline yellow"}}
                      >
                        {
                          isLoadingMoreItems ? <CircularProgress size={24} /> : 'Carregar mais itens'
                        }
                      </Button>
                    </TableCell>
                  </TableRow>

                  :

                  <TableRow className={classesRow.root} key={new Date().toISOString() + index}>
                    <TableCell className={classesCell.root} component="th" scope="row">{row.id}</TableCell>
                    <TableCell className={classesCell.root} align="right">{row.name}</TableCell>
                    <TableCell className={classesCell.root} align="right">
                        {
                            row.email ?
                            <Link to={`/admin/sendEmail?email=${row.email}`} style={{ textDecoration: 'none' }}>
                              <StyledButton
                                variant='text'
                                color="primary"
                                icon={<EmailRoundedIcon style={state.contrast === "" ? {color: "#666"} : {color: "white"}}/>}
                                text={row.email}
                              />
                            </Link> : null
                        }
                    </TableCell>
                    <TableCell className={classesCell.root} align="right">
                      {DisplayDate(row.created_at)}
                    </TableCell>
                    <TableCell className={classesCell.root} align="right">{row.score}</TableCell>
                    <TableCell className={classesCell.root} align="right">
                      {
                        row.roles.map((chip) => (
                          <ChipDiv>
                            <Chip label={chip.name} key={chip.id} 
                                style={state.contrast === "" ? {backgroundColor: "#ddd", color: "black"} : {backgroundColor: "black", color: "white", border: "1px solid white"}}
                            />
                          </ChipDiv>
                        ))
                      }
                    </TableCell>
                    <TableCell className={classesCell.root} align="right">
                      <StyledButton
                        variant="contained"
                        color="primary"
                        disabled={isUserPublisher(row.roles)}
                        onClick={() => { turnUserPublisher(row.roles, row.id) }}
                        text="Tornar publicador"
                      />
                    </TableCell>
                    <TableCell className={classesCell.root} align="right">
                      <Link to={`/admin/user?id=${row.id}`}>
                        <IconButton>
                          <VisibilityIcon style={{ fill: state.contrast === "" ? "#00bcd4" : "yellow" }} />
                        </IconButton>
                      </Link>
                    </TableCell>
                  </TableRow>
              ))}
            </TableBody>
          </TableData>
        </div>
      )
    }
  }
}

export default Users;

const ChipDiv = styled.div`
    margin-top : 0.5em;
`