/*Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana

This file is part of Plataforma Integrada MEC.

Plataforma Integrada MEC is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Plataforma Integrada MEC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Plataforma Integrada MEC.  If not, see <http://www.gnu.org/licenses/>.*/

import React, { useContext, useState } from 'react'
import { Store } from '../../Store'
import PersonAddIcon from '@material-ui/icons/PersonAdd';
import styled from 'styled-components'
import Button from '@material-ui/core/Button';
import { putRequest } from '../HelperFunctions/getAxiosConfig'
import LoginModal from './../LoginModal.js'
import SignUpModal from './../SignUpModal'

import SnackBar from '../SnackbarComponent';

export default function FollowButton(props) {

    const { state } = useContext(Store)
    const [loginOpen, setLogin] = useState(false)
    const [successfulLoginOpen, handleSuccessfulLogin] = useState(false)
    const [signUpOpen, setSignUp] = useState(false)

    const handleSignUp = () => {
        setSignUp(!signUpOpen)
    }

    const handleLogin = () => {
        setLogin(!loginOpen)
    }

    const toggleSnackbar = (event, reason) => {
        if (reason === 'clickaway') {
            return;
        }

        handleSuccessfulLogin(false);
    }

    function handleSuccess(data) {
        props.toggleFollowed()
    }

    const handleFollow = (followerID) => {
        if (followerID !== undefined) {
            const url = `/users/${followerID}/follow/`
            putRequest(url, {}, handleSuccess, (error) => { console.log(error) })
        }
    }

    return (
        <React.Fragment>
            <SnackBar
                snackbarOpen={successfulLoginOpen}
                handleClose={toggleSnackbar}
                severity={"success"}
                color={"#00acc1"}
                text={"Você está conectado(a)!"}
            />
            {/*-------------------------------MODALS---------------------------------------*/}
            <LoginModal contrast={props.contrast} open={loginOpen} handleClose={() => setLogin(false)} openSignUp={handleSignUp}
                openSnackbar={() => { handleSuccessfulLogin(true) }}
            />
            <SignUpModal contrast={props.contrast} open={signUpOpen} handleClose={handleSignUp} openLogin={handleLogin} />
            {/*----------------------------------------------------------------------------*/}
            {
                state.currentUser.id !== '' ? (
                    <StyledButton className={`${props.contrast}LinkColor`}
                        style={props.contrast === "" ? {border: "2px solid #00bcd4", borderRadius : "5px", color :"#00bcd4", backgroundColor: "white"} : {border: "1px solid white", borderRadius : "5px", color :"#00bcd4"}}
                        onClick={() => handleFollow(props.followerID)}>
                        <PersonAddIcon
                            className={`${props.contrast}IconColor`}
                            style={{
                                fontSize: "24px",
                                display: "inline-block",
                                verticalAlign: "middle",
                            }} />
                        SEGUIR
                    </StyledButton>
                )
                    :
                    (
                        <StyledButton className={`${props.contrast}LinkColor `}
                            style={props.contrast === "" ? {border: "2px solid #00bcd4", borderRadius : "5px", color :"#00bcd4", backgroundColor: "white"} : {border: "1px solid white", borderRadius : "5px", color :"#00bcd4"}}
                            onClick={() => handleLogin(true)}>
                            <PersonAddIcon
                                className={`${props.contrast}IconColor`}
                                style={{
                                    fontSize: "24px",
                                    display: "inline-block",
                                    verticalAlign: "middle",

                                }} />
                        SEGUIR
                        </StyledButton>
                    )
            }
        </React.Fragment>
    )
}

export function NoIcon(props) {
    const { state } = useContext(Store)
    const [loginOpen, setLogin] = useState(false)
    const [successfulLoginOpen, handleSuccessfulLogin] = useState(false)
    const [signUpOpen, setSignUp] = useState(false)

    const handleSignUp = () => {
        setSignUp(!signUpOpen)
    }

    const handleLogin = () => {
        setLogin(!loginOpen)
    }

    const toggleSnackbar = (event, reason) => {
        if (reason === 'clickaway') {
            return;
        }

        handleSuccessfulLogin(false);
    }

    const handleFollow = (followerID) => {
        if (followerID !== undefined) {
            const url = `/users/${followerID}/follow/`
            putRequest(url, {}, (data) => { props.toggleFollowed() }, (error) => { console.log(error) })
        }
    }

    return (
        <React.Fragment>
            <SnackBar
                snackbarOpen={successfulLoginOpen}
                handleClose={toggleSnackbar}
                severity={"success"}
                color={"#00acc1"}
                text={"Você está conectado(a)!"}
            />
            {/*-------------------------------MODALS---------------------------------------*/}
            <LoginModal contrast={props.contrast} open={loginOpen} handleClose={() => setLogin(false)} openSignUp={handleSignUp}
                openSnackbar={() => { handleSuccessfulLogin(true) }}
            />
            <SignUpModal contrast={props.contrast} open={signUpOpen} handleClose={handleSignUp} openLogin={handleLogin} />
            {/*----------------------------------------------------------------------------*/}
            {
                state.currentUser.id !== '' ? (
                    <NoIconButton contrast={state.contrast} onClick={() => handleFollow(props.followableID)}>seguir</NoIconButton>
                )
                    :
                    (
                        <NoIconButton contrast={state.contrast} className={`${props.contrast}LinkColor`} 
                        style={props.contrast === "" ? {border: "2px solid #00bcd4", borderRadius : "5px", color :"#00bcd4", backgroundColor: "white"} : {border: "1px solid white", borderRadius : "5px", color :"#00bcd4"}}
                        onClick={() => handleLogin(true)}>seguir</NoIconButton>
                    )
            }
        </React.Fragment>
    )
}

const NoIconButton = styled(Button)`
    &:hover {
        background-color: ${props => props.contrast === "" ? "" : "rgba(255,255,0,0.24) !important"};
    }
    .MuiButton-label {
        color: ${props => props.contrast === "" ? "#00bcd4 !important" : "yellow !important"};
    }
    background-color: ${props => props.contrast === "" ? "#fff !important" : "black !important"};
    border: ${props => props.contrast === "" ? "solid 1px rgba(0,188,212,.85) !important" : "solid 1px white !important"};
    font-size : 14px !important;
    border-radius : 3px !important;
    height : 36px !important;
    min-width : 88px !important;
    vertical-align : middle !important;
    align-items : center !important;
    text-align : center !important;
    padding : 0 6px !important;
    margin : 6px 8px !important;
    color: ${props => props.contrast === "" ? "#00bcd4 !important" : "yellow !important"};
    text-decoration: ${props => props.contrast === "" ? "none !important" : "underline !important"};
`

const StyledButton = styled(Button)`
    font-size : 14px important;
    font-weight : 500 !important;

    .MuiSvgIcon-root {
        font-size : 24px;
    }

    &:hover {
        color: rgb(107, 35, 142);
    }
    margin : 6px 8px !important;
`
