import React, { useEffect } from 'react';
import Paper from '@material-ui/core/Paper';
import styled from 'styled-components';
import Grid from '@material-ui/core/Grid';
import LoadingSpinner from '../LoadingSpinner';
import ResourceCardFunction from '../ResourceCardFunction';
import IconButton from '@material-ui/core/IconButton';
import ArrowBackIcon from '@material-ui/icons/ArrowBack';
import ArrowForwardIcon from '@material-ui/icons/ArrowForward';

//Image Import
import { RecursoVazio } from "ImportImages.js";

export default function ResourceTemplate({ isLoading, resources, totalResources, currPage, handlePreviousPage, handleNextPage, contrast }) {
    const totalPages = parseInt(totalResources) === 0 ? 0 : Math.ceil(totalResources / 12) - 1; //Dividing by 12 because i want to cath total pages, and results per page is 12
    const topRef = React.useRef();

    useEffect(() => {
        topRef.current.scrollIntoView();
    }, [isLoading])

    return (
        <ResourcePaper elevation={4} square contrast={contrast}>
            <div ref={topRef} />
            <div className="main">
                <Title contrast={contrast}>
                    Recursos encontrados ({totalResources})
                </Title>
                {
                isLoading ?
                    <LoadingSpinner text='Carregando recursos...' contrast={contrast} />
                    :
                    <Grid container justify='center' alignItems='center' spacing={3}>
                    {
                        resources.length >= 1 ?
                        resources.map((card) => {
                            return (
                                <Grid item key={new Date().toISOString() + card.id} >
                                    <ResourceCardFunction
                                        contrast={contrast}
                                        avatar={card.publisher ? card.publisher.avatar : ""}
                                        id={card.id}
                                        thumbnail={card.thumbnail}
                                        type={card.object_type ? card.object_type : "Outros"}
                                        title={card.name}
                                        published={card.state === "published" ? true : false}
                                        likeCount={card.likes_count}
                                        liked={card.liked}
                                        rating={card.review_average}
                                        author={card.author}
                                        tags={card.tags}
                                        href={"/recurso/" + card.id}
                                        downloadableLink={card.default_attachment_location}
                                    />
                                </Grid>
                            )
                        })
                        :
                        <NoContentDiv contrast={contrast}>
                            <h3>
                                Desculpe, não há dados nessa página.
                            </h3>
                            <img src={RecursoVazio} alt='No cards' />
                        </NoContentDiv>
                    }
                    </Grid>
                }
                {
                !isLoading &&
                <Grid container direction='row' alignItems='center' justify='center' spacing={3}>
                    <Grid item>
                        <StyledIconButton contrast={contrast} elevation={4} disabled={currPage === 0}>
                            <IconButton onClick={handlePreviousPage} disabled={currPage === 0}>
                                <ArrowBackIcon className='icon' />
                            </IconButton>
                        </StyledIconButton>
                    </Grid>
                    <Grid item>
                        <ActualPage contrast={contrast}>
                            {currPage + 1}
                        </ActualPage>
                        <TotalPages contrast={contrast}>
                            ...{totalPages + 1}
                        </TotalPages>
                    </Grid>
                    <Grid item>
                        <StyledIconButton contrast={contrast} elevation={4} disabled={currPage === totalPages}>
                            <IconButton onClick={handleNextPage} disabled={currPage === totalPages}>
                                <ArrowForwardIcon className='icon' />
                            </IconButton>
                        </StyledIconButton>
                    </Grid>
                </Grid>
                }
            </div>
        </ResourcePaper>
    )
};

const Title = styled.h4`
    text-transform: uppercase;
    font-weight: 500;
    text-align: left; 
    color: ${props => props.contrast === "" ? "#ff7f00" : "white"};
`
const NoContentDiv = styled.div`
    h3{
        color: ${props => props.contrast === "" ? "#ff7f00" : "white"};
        text-align: center;
    }
`
const ActualPage = styled.span`
    color: ${props => props.contrast === "" ? "#666" : "white"};
`
const TotalPages = styled.span`
    color: ${props => props.contrast === "" ? "#666" : "white"};
`
const StyledIconButton = styled(Paper)` 
    border-radius: 50% !important;
    background-color: ${props => props.contrast === "" ? props.disabled ? "#666" : "orange" : "black"} !important;
    .icon{
        color: ${props => props.contrast === "" ? "white": props.disabled ? "white" : "yellow"} !important;
    }
    border: ${props => props.contrast === "" ? "" : "1px solid white"} !important;
`

const ResourcePaper = styled(Paper)`
    /* height: 150px; */
    text-align: center;
    margin-top: 5px;
    margin-bottom: 30px;
    border: ${props => props.contrast === "" ? 0 : "1px solid white"};

    .main{
        background-color: ${props => props.contrast === "" ? "#fff" : "black"};
        padding: 0.5em 1em;
    }

    .textInfo{
        text-align: start;
    }
`;