/*Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana

This file is part of Plataforma Integrada MEC.

Plataforma Integrada MEC is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Plataforma Integrada MEC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Plataforma Integrada MEC.  If not, see <http://www.gnu.org/licenses/>.*/

import React, { useState } from 'react'
import FormControl from '@material-ui/core/FormControl';
import { StyledFormLabel } from '../StyledComponents.js'
import Checkbox from '@material-ui/core/Checkbox';
import { withStyles } from '@material-ui/core/styles';
import { yellow, blue } from "@material-ui/core/colors";
import FormControlLabel from '@material-ui/core/FormControlLabel';
import FormGroup from '@material-ui/core/FormGroup';

const BlueCheckBox = withStyles({
    root: {
        color: blue[400],
        '&$checked': {
            color: blue[600],
        },
    },
    checked: {},
})((props) => <Checkbox color="default" {...props} />);

const ContrastCheckBox = withStyles({
    root: {
        color: yellow[400],
        '&$checked': {
            color: yellow[600],
        },
    },
    checked: {},
})((props) => <Checkbox color="default" {...props} />);

export default function Idioma(props) {
    const [chosenLanguage, setChosenLanguage] = useState(props.initialValue ? props.initialValue : [])
    const [ids, setIds] = useState(props.initialIDValue ? props.initialIDValue : [])

    const handleChangeLanguage = (language) => {
        const languageIndex = chosenLanguage.indexOf(language.name);
        const copyChosenLanguages = [...chosenLanguage];
        const copyIds = [...ids]

        if (languageIndex > -1) {
            copyChosenLanguages.splice(languageIndex, 1);
            copyIds.splice(languageIndex, 1);
        }
        else {
            copyChosenLanguages.push(language.name);
            copyIds.push(language.id);
        }

        setChosenLanguage(copyChosenLanguages);
        setIds(copyIds);

        // if (!chosenLanguage.some(language => language === newLanguage.name)) {
        //     setChosenLanguage(chosenLanguage => [...chosenLanguage, newLanguage.name]);
        //     setIds(ids => [...ids, newLanguage.id])
        // }
        // else {
        //     if (chosenLanguage.length > 0) {
        //         setChosenLanguage(chosenLanguage.filter((language) => { return language !== newLanguage.name }));
        //         setIds(ids.filter((id) => { return id !== newLanguage.id }))
        //     }
        // }
    };


    return (
        <FormControl style={{ minWidth: "30%" }}>
            <StyledFormLabel contrast={props.contrast} component="legend" style={{ fontSize: "14px", marginBottom: "10px" }}>
                <b>Idioma</b><span>*</span>
            </StyledFormLabel>

            <FormGroup row onBlur={() => { props.onBlurCallback("language_ids", ids, props.draftID) }}>
                {
                    props.languages.map((language) => {
                        return <FormControlLabel
                            value={language}
                            key={language.name}
                            control={props.contrast === "" ? <BlueCheckBox checked={chosenLanguage.indexOf(language.name) > -1} onChange={() => handleChangeLanguage(language)} /> : <ContrastCheckBox checked={chosenLanguage.indexOf(language.name) > -1} onChange={() => handleChangeLanguage(language)} />}
                            label={<span style={props.contrast === "" ? {} : { color: "yellow", textDecoration: "underline" }}>{language.name}</span>}
                        />
                    })
                }
            </FormGroup>

            {/* <Select
                value={chosenLanguage}
                multiple
                renderValue={(selected) => selected.join(', ')}
                name="Idioma"
                onChange={handleChangeLanguage}
                onBlur={() => { props.onBlurCallback("language_ids", ids, props.draftID) }}
            >
                {
                    props.languages.map(language =>
                        <MenuItem key={language.name} value={language}>
                            <Checkbox checked={chosenLanguage.indexOf(language.name) > -1} />
                            <ListItemText primary={language.name} />
                        </MenuItem>
                    )
                }
            </Select> */}
        </FormControl>
    )
}
