/*Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana

This file is part of Plataforma Integrada MEC.

Plataforma Integrada MEC is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Plataforma Integrada MEC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Plataforma Integrada MEC.  If not, see <http://www.gnu.org/licenses/>.*/

import React from 'react'
import styled from 'styled-components'
import { Button } from '@material-ui/core';
import TextField from '@material-ui/core/TextField';
import FormHelperText from '@material-ui/core/FormHelperText';
import FormLabel from '@material-ui/core/FormLabel';
import { makeStyles } from '@material-ui/core/styles';
import Radio from '@material-ui/core/Radio';
import GetIconByName from './GetIconByName.js'

export const StyledFormHelperText = styled(FormHelperText)`
    .MuiFormHelperText-root {
        text-align : right !important;
    }
`

export const DottedBox = styled.div`
    align-self : center;
    /* width : ${props => props.thumbnail ? "100%" : "320px"}; */
    background-color : ${props => props.contrast === "" ? props.thumbnail ? "transparent" : "#f4f4f4" : "black"};
    border : ${props => props.contrast === "" ? props.thumbnail ? "2px dashed #a5a5a5" : "2px dashed #00bcd4" : "2px dashed white"};
    align-items : center;
    border-radius  : 10px;
    display : flex;
    flex-direction : column;
    padding : 20px 0;
    color : ${props => props.contrast === "" ? props.thumbnail ? "#a5a5a5" : "$666" : "white"};

    .icon {
        font-size : 40px !important;
        color : ${props => props.contrast === "" ? "#00bcd4 !important" : "white !important"}; 
        margin-bottom : 10px !important;
        vertical-align : middle !important;
        font-weight : normal !important;
        font-style : normal !important;
        line-height : 1 !important;
        letter-spacing : normal !important;
        text-transform : none !important;
        display : inline-block !important;
        white-space : nowrap !important;
        word-wrap : normal !important;
        direction : ltr !important;
        padding-right : 2px;
    }
`

export const BlueButton = styled(Button)`
    &:hover {
      background-color: ${props => props.contrast === "" ? "#00acc1 !important" : "rgba(255,255,0,0.24) !important"};
    }
    color : ${props => props.contrast === "" ? "#fff !important" : "yellow !important"};
    text-decoration: ${props => props.contrast === "" ? "none !important" : "underline !important"};
    background-color : ${props => props.contrast === "" ? "#00bcd4 !important" : "black !important"};
    border : ${props => props.contrast === "" ? "none !important" : "1px solid white !important"};
    box-shadow : 0 2px 5px 0 rgba(0,0,0,.26) !important;
    font-weight : 600 !important;
`

export const GrayButton = styled(Button)`
    &:hover {
        background-color: ${props => props.contrast === "" ? "rgba(158,158,158,0.2) !important" : "rgba(255,255,0,0.24) !important"};
    }
    color: ${props => props.contrast === "" ? "#666" : "yellow"} !important;
    text-decoration: ${props => props.contrast === "" ? "none" : "yellow underline" } !important;

    background-color : ${props => props.contrast === "" ? "transparent !important" : "black !important"};
    border : ${props => props.contrast === "" ? "none !important" : "1px solid white !important"};
    font-weight : 600 !important;

    .icon {
        vertical-align : middle !important;
        color : ${props => props.contrast === "" ? "#666 !important" : "white !important"};
        font-weight : normal !important;
        font-style : normal !important;
        font-size : 24px !important;
        line-height : 1 !important;
        letter-spacing : normal !important;
        text-transform : none !important;
        display : inline-block !important;
        white-space : nowrap !important;
        word-wrap : normal !important;
        direction : ltr !important;
        padding-right : 2px;
        color : inherit !important;
    }

    .button-text {
        cursor : pointer;
        line-height : 36px;
        text-align : center;
        color : currentColor;
        white-space : nowrap;
        text-transform : uppercase;
        font-weight : 600;
        font-size : 14px;
        font-style : inherit;
        font-variant : inherit;
    }

    margin-left : 8px !important;
    margin-right : 8px !important;
`

export const WrapperBox = styled.div`
    padding : 0;
    margin-bottom : 15px;
    display : block;
    border-radius : 3px;
    box-shadow : 0 1px 3px rgba(0,0,0,.12),0 1px 2px rgba(0,0,0,.24);
    font-size : 14px;
    background: ${props => props.contrast === "" ? " #fff" : "black"};
    border: ${props => props.contrast === "" ? " " : "1px solid white"};

    .inner {
        display : block;
        padding : 20px;
        background: ${props => props.contrast === "" ? " #fff" : "black"};
    }

    .upload-title {
        text-align : center;
        font-size : 26px;
        margin-bottom : 10px;
        font-weight : lighter;
        color: ${props => props.contrast === "" ? "" : "white"};
    }

    .flex-column {
        display: -webkit-box;
        display: -ms-flexbox;
        display: flex;
        -webkit-box-orient: vertical;
        -webkit-box-direction: normal;
        -ms-flex-direction: column;
        flex-direction: column;

        p {
            margin : 0 0 10px;
            color: ${props => props.contrast === "" ? "" : "white"};
        }

        .buttons-div {
            padding-top : 10px;
            padding-left : 15px;
            padding-right : 15px;
            display: flex;
            flex-direction : row;
            justify-content : space-evenly;
            text-align : center;
        }
    }

    .strike-box {
        display : flex;
        flex-direction : row;
        justify-content : center;

        .strike {
            border-bottom : solid 1px #e5e5e5;
            display : inline-block;
            vertical-align : middle;
            width : 40%;
            margin-bottom : 2em;
        }

        h3 {
            margin : 20px 0;
            font-weight : 400;
            overflow : hidden;
            text-align : center;
            font-size : 14px;
            color: ${props => props.contrast === "" ? "#666" : "white"};
            padding : 0 5px;
        }
    }

    .enviar-link-texto {
        padding-left : 15px;
        padding-right : 15px;
        text-align : center;
        font-size : 14px;
        margin-bottom : 5px;

        img {
            height : 35px;
            vertical-align : middle;
        }
    }

    .uploading {
        margin-top : 30px;

        .upload-item {
            margin-bottom : 5px;

            .item-info {
                display : flex;
                flex-direction : row;
                justify-content : space-between;
                align-items : center;
                padding : 5px 0;
                font-size : 14px;

                .icon {
                    vertical-align : middle !important;
                    font-weight : normal !important;
                    font-style : normal !important;
                    font-size : 24px !important;
                    line-height : 1 !important;
                    letter-spacing : normal !important;
                    text-transform : none !important;
                    display : inline-block !important;
                    white-space : nowrap !important;
                    word-wrap : normal !important;
                    direction : ltr !important;
                    padding-right : 2px;
                }

                .file-status {
                    .icon-margin {
                        color: ${props => props.contrast === "" ? "#00bcd4" : "white"};
                        margin-right : 5px;
                    }
                    .MuiLinearProgress-root {
                        width : 100% !important;
                    }
                }

                .icon-remove {
                    color : #666;
                    font-size : 20px;
                }
            }
        }

        .warning {
            padding: 40px 0 20px 0;
            margin-top: 40px;
            border-top: solid 1px #f4f4f4;
            text-align: center;
            color: ${props => props.contrast === "" ? "" : "white"};

            span {
                font-size : 16px;
                font-weight : lighter;
                color: ${props => props.contrast === "" ? "" : "white"};
            }
        }
    }
`

export const InfoBox = styled.div`
    background: ${props => props.contrast === "" ? " #fff" : "black"};
    border: ${props => props.contrast === "" ? " " : "1px solid white"};
    padding : 30px;
    box-shadow : 0 1px 3px rgba(0,0,0,.12),0 1px 2px rgba(0,0,0,.24);
    margin-bottom : 30px;
    border-radius : 3px;

    .cabecalho {
        display : flex;
        flex-direction : column;
        align-items : center;
        margin-bottom : 30px;

        h2 {
            margin-top : 0;
            font-size : 26px;
            font-weight : lighter;
            margin-bottom : 10px;
        }

        .feedback-upload {
            display : flex;
            flex-direction : column;
            justify-content : center;
            text-align : center
            margin-top : 20px;
            width : 65%;
        }
    }
`
export const ObjTypeBox = styled.div`
    height : 100px;
    width : 100px;
    border-radius : 10px;
    background-color : ${props => props.contrast === "" ? "#f4f4f4" : "black"};
    border : ${props => props.contrast === "Contrast" ? props.checked ? "1px solid white" : "0" : props.checked ? "1px solid #00bcd4" : "0"};
    font-weight : ${props => props.checked ? "bold" : "lighter"};
    
    box-sizing: border-box;
    -moz-box-sizing: border-box;
    -webkit-box-sizing: border-box;

    span {
        padding-top : 5%;
        display : flex;
        flex-direction : column;
        justify-content : center;

        .icon {
            color : #00bcd4;
            align-self : center;
            height : 48px;
            width : 48px;
        }

        p {
            color : ${props => props.contrast === "" ? "#00bcd4" : "yellow"};
            text-decoration : ${props => props.contrast === "Contrast" ? props.checked ? "none" : "underline" : "none"};
            height : 28px;
            font-size : 14px;
            text-align : center;
            line-height : 14px;
        }
    }
`

export const OutroAutorTextField = styled(TextField)`
    font-size : 14px;
    width : 100% !important;

    .MuiOutlinedInput-root {
        &.Mui-focused fieldset {
            border-color: ${props => props.contrast === "" ? "#00bcd4" : "yellow"};
        }
        fieldset {
            border-color: ${props => props.contrast === "" ? "#666" : "white"};
        }
    }

    label{
        color: ${props => props.contrast === "" ? "#666" : "white"};
    }

    label.Mui-focused {
        color: ${props => props.contrast === "" ? "#00bcd4" : "yellow"};
    }

    label.Mui-focused.Mui-error {
        color : red;
    }

    .MuiFormHelperText-root {
        text-align : left;
        color: ${props => props.contrast === "" ? "#666" : "white"};
    }
`

export const StyledFormLabel = styled(FormLabel)`
    b {
        color: ${props => props.contrast === "" ? "#666 !important" : "white !important"};
    }
    span {
        color: ${props => props.contrast === "" ? "#a5a5a5" : "white"};
    }
`

export const StyledTextField = styled(TextField)`
    font-size : 14px;
    width : 100% !important;

    .MuiFormHelperText-root {
        text-align : left;
        color: ${props => props.contrast === "" ? "#666" : "white"};
    }

    .MuiFormHelperText-root.Mui-error {
        text-align : left;
        color: ${props => props.contrast === "" ? "red" : "#e75480"};
    }

    .MuiInput-underline::after {
        border-color: ${props => props.contrast === "" ? "#00bcd4" : "yellow"};
    }

    .MuiInput-underline.Mui-error::after {
        border-color: ${props => props.contrast === "" ? "red" : "#e75480"};
    }

    .MuiOutlinedInput-root {
        &.Mui-focused.Mui-error fieldset{
            border-color: ${props => props.contrast === "" ? "red" : "#e75480"};
        }

        &.Mui-error fieldset{
            border-color: ${props => props.contrast === "" ? "red" : "#e75480"};
        }

        &.Mui-focused fieldset {
            border-color: ${props => props.contrast === "" ? "#00bcd4" : "yellow"};
        }
        fieldset {
            border-color: ${props => props.contrast === "" ? "#666" : "white"};
        }
    }

    label{
        color: ${props => props.contrast === "" ? "#666" : "white"};
    }

    .MuiFormLabel-asterisk {
        color: ${props => props.contrast === "" ? "#666" : "white"};
    }

    .MuiFormLabel-asterisk.Mui-error {
        color: ${props => props.contrast === "" ? "red" : "#e75480"};
    }

    label.Mui-focused {
        color: ${props => props.contrast === "" ? "#00bcd4" : "yellow"};
    }

    label.Mui-focused.Mui-error {
        color: ${props => props.contrast === "" ? "red" : "#e75480"};
    }

    label.Mui-error {
        color: ${props => props.contrast === "" ? "red" : "#e75480"};
    }
`

const useStyles = makeStyles({
    root: {
        '&:hover': {
            backgroundColor: 'transparent',
        },
    }
})

export function StyledRadio(props) {
    const classes = useStyles();
    return (
        <Radio
            className={classes.root}
            disableRipple
            checkedIcon={
                <ObjTypeBox contrast={props.contrast} checked>
                    <span>
                        {GetIconByName(props.label)}
                        <p>{props.label}</p>
                    </span>
                </ObjTypeBox>
            }
            icon={
                <ObjTypeBox contrast={props.contrast}>
                    <span>
                        {GetIconByName(props.label)}
                        <p>{props.label}</p>
                    </span>
                </ObjTypeBox>
            }
            {...props}
        />
    )
}

export const StyledDiv = styled.div`
    display : flex;
    margin-top : 30px;
    justify-content : space-evenly;
 `

export const OrangeButton = styled(Button)`
    max-height : 36px !important;
    box-shadow : 0 2px 5px 0 rgba(0,0,0,.26) !important;
    font-weight : 600 !important;
    background: ${props => props.contrast === "" ? " #ff7f00  !important" : "black !important"};
    color: ${props => props.contrast === "" ? "rgba(255,255,255,0.87) !important" : "yellow !important"};
    border: ${props => props.contrast === "" ? "" : "1px solid white !important"};
    text-decoration: ${props => props.contrast === "" ? "none !important" : "underline !important"};
    margin-left : 8px !important;
    margin-right : 8px !important;
    &:hover {
        background: ${props => props.contrast === "" ? "" : "rgba(255,255,0,0.24) !important"};
    }
 `

export const GreyButton = styled(Button)`
    background: ${props => props.contrast === "" ? "transparent !important" : "black !important"};
    color: ${props => props.contrast === "" ? "#666 !important" : "yellow !important"};
    border: ${props => props.contrast === "" ? "" : "1px solid white !important"};
    text-decoration: ${props => props.contrast === "" ? "none !important" : "underline !important"};
    outline : none !important;
    text-align : center !important;

    margin-left : 8px !important;
    margin-right : 8px !important;

    .button-text {
        cursor : pointer;
        text-align : center;
        color : currentColor;
        white-space : nowrap;
        text-transform : uppercase;
        font-weight : 600 !important;
        font-style : inherit;
        font-variant : inherit;
    }
 `

export const Background = styled.div`
    padding-top : 40px;
    background: ${props => props.contrast === "" ? "#f4f4f4" : "black"};
    color: ${props => props.contrast === "" ? "#666" : "white"};

    .container {
        padding : 0;
        margin-right : auto;
        margin-left : auto;
        background: ${props => props.contrast === "" ? "#f4f4f4" : "black"};
        color: ${props => props.contrast === "" ? "#666" : "white"};


        @media screen and (min-width: 768px) {
            width : 750px;
        }
        @media screen and (min-width: 992px) {
            width : 970px;
        }
        @media screen and (min-width: 1200px) {
            width : 1170px;
        }
    }
 `
