/*Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana

This file is part of Plataforma Integrada MEC.

Plataforma Integrada MEC is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Plataforma Integrada MEC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Plataforma Integrada MEC.  If not, see <http://www.gnu.org/licenses/>.*/
import React, {useState, useContext, useEffect} from 'react';
import { Store } from '../../Store.js';
import {apiDomain} from '../../env';
import {CoverContainer} from '../TabPanels/StyledComponents.js'
import IconButton from '@material-ui/core/IconButton';
import PhotoCamera from '@material-ui/icons/PhotoCamera';
import Tooltip from '@material-ui/core/Tooltip';
import ModalAlterarCover from '../ModalAlterarCover/ModalAlterarCover.js'

export default function Cover (props) {
    const {state} = useContext(Store)

    const WIDTH = window.innerWidth; 

    const [currentCover, setCoverImg] = useState(state.currentUser.cover_file_name)
    const [tempCover, setTempCover] = useState('')

    const [open, toggleOpen] = useState(false)
    const controlModal = () => {toggleOpen(!open)}

    const updateCover = (selectorFiles) => {
        const objectURL = URL.createObjectURL(selectorFiles[0])
        setTempCover(objectURL)
        controlModal()
    }

    useEffect( () => {
        setCoverImg(state.currentUser.cover)
    }, state.currentUser.cover)
    
    return (
        <>
            <ModalAlterarCover
                contrast={props.contrast}
                open = {open}
                handleClose={controlModal}
                cover={tempCover}
                id={props.id}
            />
            <CoverContainer>
                {currentCover && <img src={apiDomain + currentCover} alt = '' style= {{width:"100%", height:"100%", objectFit : "cover" }}/>}
                <input accept="image/*" style = {{display:"none"}} id="choose-cover-file" type="file" onChange={(e) => updateCover(e.target.files)}/>
                <label htmlFor="choose-cover-file">
                {
                    WIDTH >= 545 ? 
                    <Tooltip title={<span style={{fontSize:"14px", overflow:"hidden", transition:"all .5s ease"}}>ALTERAR CAPA</span>} placement="left">
                        <IconButton style={{position:"absolute",right:"0",bottom: "0",color:"#fff"}}color="primary" aria-label="upload picture" component="span">
                            <PhotoCamera />
                        </IconButton>
                    </Tooltip> 
                    : 
                    <Tooltip title={<span style={{fontSize:"14px", overflow:"hidden", transition:"all .5s ease"}}>ALTERAR CAPA</span>} placement="left">
                        <IconButton style={{position:"absolute",left:"0",top: "0",color:"#fff"}}color="primary" aria-label="upload picture" component="span">
                            <PhotoCamera />
                        </IconButton>
                    </Tooltip>
                }
                    
                </label>
            </CoverContainer>
        </>
    )
}
