/*Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana

This file is part of Plataforma Integrada MEC.

Plataforma Integrada MEC is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Plataforma Integrada MEC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Plataforma Integrada MEC.  If not, see <http://www.gnu.org/licenses/>.*/
import React, { useState, useContext, useEffect } from "react";
import Card from "@material-ui/core/Card";
import CardActions from "@material-ui/core/CardActions";
import { Button } from "@material-ui/core";
import LabeledCheckbox from "../Components/Checkbox.js";
import styled from "styled-components";
import { device } from "../Components/device.js";
import { Store } from "../Store.js";
import IllegalContentModal from "../Components/IllegalContentModal.js";
import PublicationPermissionsContent from "../Components/PublicationPermissionsContent.js";
import { getRequest } from '../Components/HelperFunctions/getAxiosConfig';
import LoadingSpinner from '../Components/LoadingSpinner';

const CardStyled = styled(Card)`
    box-sizing: border-box;
    background-color: white;
    max-width: 1700px;
    @media ${device.mobileM} {
        width: 100%;
        height: 100%;
    }
`;

const StyledContinuar = styled(Button)`
    font-family: "Roboto", sans serif;
    font-style: normal;
    font-weight: 500;
    line-height: 22px;
    font-size: 15px;
    letter-spacing: 0.01em;
    padding: 7px;
    border-radius: 5px;
    color: ${props => props.disable === true ? props.contrast === "" ? "#666" : "white" : props.contrast === "" ? "white" : "yellow"} !important;
    text-decoration: ${props => props.disable === true ? props.contrast === "" ? "none" : "none" : props.contrast === "" ? "none" : "yellow underline"} !important;
    background-color: ${props => props.disable === true ? props.contrast === "" ? "#E9E9E9" : "black" : props.contrast === "" ? "#52BCD4" : "black"} !important;
    border: ${props => props.disable === true ? props.contrast === "" ? "none" : "1px solid white" : props.contrast === "" ? "none" : "1px solid white"} !important;
`;

const StyledCancelar = styled(Button)`
    font-family: "Roboto", sans serif;
    font-style: normal;
    font-weight: 500;
    line-height: 22px;
    font-size: 15px;
    letter-spacing: 0.01em;
    padding: 7px;
    border-radius: 5px;
    color: ${props => props.contrast === "" ? "#666" : "yellow"} !important;
    text-decoration: ${props => props.contrast === "" ? "none" : "yellow underline"} !important;
    background-color: ${props => props.contrast === "" ? "white" : "black"} !important;
    border: none;
`;

const Background = styled.div`
    padding-top : 40px;
    background-color: ${props => props.contrast === "" ? "#f4f4f4" : "black"};
    color : #666;
    padding-bottom : 40px;

    .container {
        padding : 0;
        margin-right : auto;
        margin-left : auto;

        @media screen and (min-width: 768px) {
            width : 750px;
        }
        @media screen and (min-width: 992px) {
            width : 970px;
        }
        @media screen and (min-width: 1200px) {
            width : 1170px;
        }
    }
`

export default function PermissionsContainer(props) {
    const { state, dispatch } = useContext(Store);
    const [loading, setLoading] = useState(true);
    const [unavailableCheckbox, setCheckboxAvailability] = useState(true);
    const [unavailableButton, setButtonAvailability] = useState(true);

    const [questionsArr, setQuestionsArr] = useState([]);

    const [radios, setRadioValues] = useState({});
    const [modalOpen, setModalOpen] = useState(false);

    const closeModal = () => {
        setModalOpen(false);
        props.history.push("/termos-publicar-recurso");
        window.scrollTo(0, 0);
    };

    const handleChecked = e => {
        setButtonAvailability(!unavailableButton);
    };

    const handleRadios = e => {
        let radioTmp2 = {id: parseInt(e.target.name), value: e.target.value};
        let temp = radios;
        const index = temp.findIndex(x => x.id === parseInt(e.target.name));

        temp[index] = radioTmp2;

        setRadioValues(temp);
        setCheckboxAvailability(!(radios.every((radio) => radio.value === "Não")));
    };

    const handleAgreement = () => {
        if (radios.some((radio) => radio === "Sim")) {
            setModalOpen(true);
        } else {
            dispatch({
                type: "USER_AGREED_TO_PUBLICATION_PERMISSIONS",
                userAgreement: true
            });

            props.history.push("/upload");
        }
    };

    function handleSuccess(data) {
        var radioTmp = [];

        data.forEach(element => {
            var radioTmp2 = {id: element.id, value: ""};

            if (element.status === "active" && element.id !== 4) {
                radioTmp.push(radioTmp2);
            }
        });

        setQuestionsArr(data);
        setRadioValues(radioTmp);

        setLoading(false);
    }

    useEffect(() => {
        const url = `/questions/`

        getRequest(url, handleSuccess, (error) => { console.log(error) })

    }, [])

    const redirect = () => {
        props.history.push("/termos-publicar-recurso");
    };

    const redirectToHome = () => {
        props.history.push("/");
    };

    return (
        <>
        {!loading ? 
        (
            state.userAgreedToPublicationTerms ? (
                [
                <>
                    <IllegalContentModal
                        contrast={props.contrast}
                        open={modalOpen}
                        handleClose={closeModal}
                        disableBackdropClick={true}
                    />
                    <Background contrast={state.contrast}>
                        <div className="container">
                            <CardStyled variant="outlined">
                                <PublicationPermissionsContent contrast={state.contrast} handleRadios={handleRadios} questionsArr={questionsArr}/>
                                <CardActions
                                    style={state.contrast === "" ? { justifyContent: "center", padding: "25px", borderTop: "2px solide #dadada" } : { justifyContent: "center", padding: "25px", borderTop: "2px solide #dadada", backgroundColor: "black" }}
                                >
                                    <div>
                                        <div style={{ fontSize: "14px" }}>
                                            <LabeledCheckbox
                                                contrast={state.contrast}
                                                disabled={unavailableCheckbox}
                                                label={
                                                    <span className={`${state.contrast}LinkColor`} style={{ fontSize: "15px" }}>
                                                        Li e permito a publicação do meu recurso na
                                                        Plataforma Integrada de RED do MEC, assim como
                                                        atesto que o meu recurso atende aos critérios
                                                        especificados acima.
                                                    </span>
                                                }
                                                handleChange={handleChecked}
                                            />
                                            <div
                                                style={{ justifyContent: "left", display: "flex", marginTop: "15px" }}
                                            >
                                                <StyledContinuar
                                                    disabled={unavailableButton || unavailableCheckbox}
                                                    disable={unavailableButton || unavailableCheckbox}
                                                    contrast={state.contrast}
                                                    onClick={handleAgreement}
                                                >
                                                    Continuar
                                                </StyledContinuar>
                                                <StyledCancelar onClick={redirectToHome} contrast={state.contrast}>
                                                    Cancelar
                                                </StyledCancelar>
                                            </div>
                                        </div>
                                    </div>
                                </CardActions>
                            </CardStyled>
                        </div>
                    </Background>
                </>
                ]
            ) : (
                <>{redirect()}</>
            )
        )
        :
        (
            <LoadingSpinner contrast={state.contrast} text="Carregando..." />
        )
        }
        </>
    );
}
